@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: decmain.cpp,v 1.25 2007/12/11 02:27:22 asuraparaju Exp $ $Name: Dirac_0_9_1 $
+* $Id: decmain.cpp,v 1.28 2008/05/27 01:29:52 asuraparaju Exp $ $Name: Dirac_0_10_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -65,46 +65,11 @@ const char *chroma2string (dirac_chroma_t chroma)
     return "Unknown";
 }
 
-const char *ftype2string (dirac_frame_type_t ftype, dirac_reference_type_t rtype)
-{
-    switch (ftype)
-    {
-    case INTRA_FRAME:
-    {
-        switch (rtype)
-        {
-            case REFERENCE_FRAME:
-                return "Intra Ref Frame";
-            case NON_REFERENCE_FRAME:
-                return "Intra Non-Ref Frame";
-            default:
-                return "Intra Unknown-Ref Frame";
-        }
-    }
-    case INTER_FRAME:
-    {
-        switch (rtype)
-        {
-            case REFERENCE_FRAME:
-                return "Inter Ref Frame";
-            case NON_REFERENCE_FRAME:
-                return "Inter Non-Ref Frame";
-            default:
-                return "Inter Unknown-Ref Frame";
-        }
-    }
-    
-    default:
-        break;
-    }
-    return "Unknown";
-}
-
 static void WritePicData (dirac_decoder_t *decoder, FILE *fp)
 {
     assert (decoder != NULL);
     assert (fp);
-    
+
     assert(decoder->fbuf);
 
     assert(decoder->fbuf->buf[0]);
@@ -171,11 +136,11 @@ static void DecodeDirac (const char *iname, const char *oname)
 
 
     start_t=clock();
-    do 
+    do
     {
         /* parse the input data */
         state = dirac_parse(decoder);
-        
+
         switch (state)
         {
         case STATE_BUFFER:
@@ -198,7 +163,7 @@ static void DecodeDirac (const char *iname, const char *oname)
 
             if (verbose)
             {
-                fprintf (stdout, "\nSEQUENCE : major_ver=%d minor_version=%d profile=%d level=%d width=%d height=%d chroma=%s chroma_width=%d chroma_height=%d frame_rate=%d/%d, source_sampling=%s topfieldfirst=%s", 
+                fprintf (stdout, "\nSEQUENCE : major_ver=%d minor_version=%d profile=%d level=%d width=%d height=%d chroma=%s chroma_width=%d chroma_height=%d frame_rate=%d/%d, source_sampling=%s topfieldfirst=%s",
                 decoder->parse_params.major_ver,
                 decoder->parse_params.minor_ver,
                 decoder->parse_params.profile,
@@ -210,7 +175,7 @@ static void DecodeDirac (const char *iname, const char *oname)
                 decoder->src_params.chroma_height,
                 decoder->src_params.frame_rate.numerator,
                 decoder->src_params.frame_rate.denominator,
-                decoder->src_params.source_sampling == 0 ? "progressive" : 
+                decoder->src_params.source_sampling == 0 ? "progressive" :
                 ( decoder->src_params.source_sampling == 1 ? "interlaced" : "UNKNOWN" ),
                 decoder->src_params.topfieldfirst ? "yes" : "no");
             }
@@ -224,7 +189,7 @@ static void DecodeDirac (const char *iname, const char *oname)
             buf[2] = (unsigned char *)malloc (decoder->src_params.chroma_width * decoder->src_params.chroma_height);
             dirac_set_buf (decoder, buf, NULL);
 
-         
+
             }
             break;
 
@@ -234,40 +199,16 @@ static void DecodeDirac (const char *iname, const char *oname)
             */
             if (verbose)
                 fprintf (stdout, "\nSEQUENCE_END");
-            
-            FreeFrameBuffer(decoder);
-            break;
-        
-        case STATE_PICTURE_START:
-            /*
-            * Start of frame detected. If decoder is too slow and frame can be
-            * skipped, inform the parser to skip decoding the frame
-            */
-            if (verbose)
-            {
-                fprintf (stdout, "\nPICTURE_START : frame_type=%s frame_num=%d",
-                    ftype2string(decoder->frame_params.ftype, decoder->frame_params.rtype),
-                    decoder->frame_params.fnum);
-            }
-            /* Just for testing skip every Non-reference frame */
-            if (skip && decoder->frame_params.rtype == NON_REFERENCE_FRAME)
-            {
-                if (verbose)
-                    fprintf (stdout, "\n              : Skipping frame");
 
-                dirac_skip (decoder, 1);
-            }
-            else
-                dirac_skip (decoder, 0);
+            FreeFrameBuffer(decoder);
             break;
 
         case STATE_PICTURE_AVAIL:
             num_frames++;
             if (verbose)
             {
-                fprintf (stdout, "\nPICTURE_AVAIL : frame_type=%s frame_num=%d",
-                    ftype2string(decoder->frame_params.ftype, decoder->frame_params.rtype), 
-                    decoder->frame_params.fnum);
+                fprintf (stdout, "\nFRAME_AVAIL : frame_num=%d",
+                    decoder->frame_num);
             }
             /* picture available for display */
             WritePicData(decoder, fpdata);
