@@ -1,6 +1,6 @@
  /* ***** BEGIN LICENSE BLOCK *****
  *
- * $Id: encmain.cpp,v 1.65 2008/01/03 03:36:30 asuraparaju Exp $ $Name: Dirac_0_9_1 $
+ * $Id: encmain.cpp,v 1.74 2008/05/27 01:29:53 asuraparaju Exp $ $Name: Dirac_0_10_0 $
  *
  * Version: MPL 1.1/GPL 2.0/LGPL 2.1
  *
@@ -54,6 +54,9 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <cstdlib>
+#include <cstring>
+#include <climits>
 
 using namespace std;
 
@@ -83,6 +86,10 @@ static void display_help()
     cout << "\nHD1080I50         bool    false         Use HD-1080I50 compression presets";
     cout << "\nHD1080P60         bool    false         Use HD-1080P60 compression presets";
     cout << "\nHD1080P50         bool    false         Use HD-1080P50 compression presets";
+    cout << "\nUHDTV4K60         bool    false         Use UHDTV 4K60 compression presets";
+    cout << "\nUHDTV4K50         bool    false         Use UHDTV 4K50 compression presets";
+    cout << "\nUHDTV8K60         bool    false         Use UHDTV 8K60 compression presets";
+    cout << "\nUHDTV8K50         bool    false         Use UHDTV 8K50 compression presets";
     cout << "\nDC2K24            bool    false         Use DIGITAL CINEMA 2K compression presets";
     cout << "\nDC4K24           bool    false          Use DIGITAL CINEMA 4K compression presets";
     cout << "\nfull_search     ulong ulong  0UL 0UL         Use full search motion estimation";
@@ -111,7 +118,7 @@ static void display_help()
     cout << "\nmulti_quants      bool    false         Use multiple quantisers";
     cout << "\nmv_prec           string  false         MV Pixel Precision (1, 1/2, 1/4, 1/8)";
     cout << "\nno_spartition     bool    false         Do not use spatial partitioning while coding transform data";
-    cout << "\ndenoise           bool    false         Denoise input before coding (NB: PSNR stats will relate to denoised video)";
+    cout << "\nprefilter         string/int NO_PF 0    Prefilter input giving filter name (NO_PF, CWM, RECTLP, DIAGLP) and strength (0-10)";
     cout << "\nuse_vlc           bool    false         Use VLC for entropy coding of coefficients";
     cout << "\nverbose           bool    false         verbose mode";
     cout << "\nlocal             bool    false         Write diagnostics & locally decoded video";
@@ -194,8 +201,8 @@ bool WriteDiagnosticsData (std::ofstream &fdata, dirac_encoder_t *encoder)
         fdata.exceptions (ios::failbit | ios::badbit);
         try
         {
-            fdata << std::endl << "[frame:" << instr.fnum << "]";
-            if (instr.ftype == INTRA_FRAME)
+            fdata << std::endl << "[frame:" << instr.pnum << "]";
+            if (instr.ptype == INTRA_PICTURE)
             {
                 fdata << ">intra" << std::endl;
                 return true;
@@ -399,6 +406,22 @@ const string ChromaToString (dirac_chroma_t chroma)
     return string("Unknown");
 }
 
+const string PrefilterToString(dirac_prefilter_t pf)
+{
+    switch (pf)
+    {
+    case CWM:
+        return string("CWM");
+    case RECTLP:
+        return string("RECTLP");
+    case DIAGLP:
+        return string("DIAGLP");
+    default:
+        return string("NO_PF");
+    };
+
+}
+
 dirac_chroma_t StringToChroma (const char* chroma)
 {
     if (strcmp(chroma, "YUV444P") == 0)
@@ -498,7 +521,7 @@ void display_codec_params(dirac_encoder_context_t &enc_ctx)
     std::cout << " \tWavelet depth=" << enc_ctx.enc_params.wlt_depth << std::endl;
     std::cout << " \tSpatial Partitioning=" << (enc_ctx.enc_params.spatial_partition ? "true" : "false") << std::endl;
     std::cout << " \tMultiple Quantisers=" << (enc_ctx.enc_params.multi_quants ? "true" : "false") << std::endl;
-    std::cout << " \tDenoising input=" << (enc_ctx.enc_params.denoise ? "true" : "false") << std::endl;
+    std::cout << " \tPrefilter=" << PrefilterToString(enc_ctx.enc_params.prefilter) << std::endl;
     std::cout << " \tField coding=" << (enc_ctx.enc_params.picture_coding_mode == 1? "true" : "false") << std::endl;
     std::cout << " \tLossless Coding=" << (enc_ctx.enc_params.lossless ? "true" : "false") << std::endl;
     std::cout << " \tEntropy Coding=" << (enc_ctx.enc_params.using_ac ? "Arithmetic Coding" : "Variable Length Coding") << std::endl;
@@ -610,6 +633,26 @@ bool parse_command_line(dirac_encoder_context_t& enc_ctx, int argc, char **argv)
             preset = VIDEO_FORMAT_HD_1080P50;
             parsed[i] = true;
         }
+        else if ( strcmp (argv[i], "-UHDTV4K60") == 0 )
+        {
+            preset = VIDEO_FORMAT_UHDTV_4K60;
+            parsed[i] = true;
+        }
+        else if ( strcmp (argv[i], "-UHDTV4K50") == 0 )
+        {
+            preset = VIDEO_FORMAT_UHDTV_4K50;
+            parsed[i] = true;
+        }
+        else if ( strcmp (argv[i], "-UHDTV8K60") == 0 )
+        {
+            preset = VIDEO_FORMAT_UHDTV_8K60;
+            parsed[i] = true;
+        }
+        else if ( strcmp (argv[i], "-UHDTV8K50") == 0 )
+        {
+            preset = VIDEO_FORMAT_UHDTV_8K50;
+            parsed[i] = true;
+        }
         else if ( strcmp (argv[i], "-DC2K24") == 0 )
         {
             preset = VIDEO_FORMAT_DIGI_CINEMA_2K24;
@@ -868,10 +911,46 @@ bool parse_command_line(dirac_encoder_context_t& enc_ctx, int argc, char **argv)
             parsed[i] = true;
             enc_ctx.enc_params.spatial_partition = false;
         }
-        else if ( strcmp(argv[i], "-denoise") == 0 )
+        else if ( strcmp(argv[i], "-prefilter") == 0 )
         {
             parsed[i] = true;
-            enc_ctx.enc_params.denoise = true;
+            i++;
+            if(strcmp(argv[i], "DIAGLP")==0)
+            {
+                parsed[i] = true;
+                enc_ctx.enc_params.prefilter = DIAGLP;
+                i++;
+                enc_ctx.enc_params.prefilter_strength =
+                strtoul(argv[i],NULL,10);
+                parsed[i] = true;
+            }
+            else if(strcmp(argv[i], "RECTLP")==0)
+            {
+                parsed[i] = true;
+                enc_ctx.enc_params.prefilter = RECTLP;
+                i++;
+                enc_ctx.enc_params.prefilter_strength =
+                strtoul(argv[i],NULL,10);
+                parsed[i] = true;
+            }
+            else if(strcmp(argv[i], "CWM")==0)
+            {
+                parsed[i] = true;
+                enc_ctx.enc_params.prefilter = CWM;
+                i++;
+                enc_ctx.enc_params.prefilter_strength =
+                strtoul(argv[i],NULL,10);
+                parsed[i] = true;
+            }
+            else if(strcmp(argv[i], "NO_PF")==0)
+            {
+                parsed[i] = true;
+                enc_ctx.enc_params.prefilter = NO_PF;
+                i++;
+                enc_ctx.enc_params.prefilter_strength =
+                strtoul(argv[i],NULL,10);
+                parsed[i] = true;
+            }
         }
         else if ( strcmp(argv[i], "-wlt_depth") == 0 )
         {
@@ -879,7 +958,7 @@ bool parse_command_line(dirac_encoder_context_t& enc_ctx, int argc, char **argv)
             i++;
             enc_ctx.enc_params.wlt_depth = strtoul(argv[i],NULL,10);
 #if defined(HAVE_MMX)
-            if(enc_ctx.enc_params.wlt_depth > 5)
+            if(enc_ctx.enc_params.wlt_depth > 4)
                 cerr << "Exceeds maximum transform depth ";
            else
                 parsed[i] = true;
@@ -1062,7 +1141,7 @@ int main (int argc, char* argv[])
     if ( end_pos == -1 )
         end_pos = INT_MAX;
 
-    /* don't try and skup frames if they aren't any to skip, eg
+    /* don't try and skip frames if they aren't any to skip, eg
      * this won't work on nonseekable filehandles. */
     if (start_pos && !Skip( ip_pic_ptr, start_pos, frame_size ))
     {
@@ -1096,16 +1175,17 @@ int main (int argc, char* argv[])
        WriteDiagnosticsHeader ( *outimt, encoder );
 
 
-    int pictures_written = 0;
+    int frames_loaded = 0;
     dirac_encoder_state_t state;
 
     clock_t start_t, stop_t;
     start_t = clock();
 
-    bool end_of_file = false;
+    bool go = true;
     do
     {
-        if (ReadPicData( ip_pic_ptr, frame_buf, frame_size ) == true)
+        if (frames_loaded <= (end_pos - start_pos) &&
+            ReadPicData( ip_pic_ptr, frame_buf, frame_size ) == true)
         {
             if (dirac_encoder_load( encoder, frame_buf, frame_size ) < 0)
             {
@@ -1113,28 +1193,34 @@ int main (int argc, char* argv[])
                           << std::endl;
                 return EXIT_FAILURE;
             }
+            frames_loaded++;
         }
         else
         {
-           end_of_file = true; //eof
+           // push end of stream
+           dirac_encoder_end_sequence( encoder );
         }
         do
         {
             encoder->enc_buf.buffer = video_buf;
             encoder->enc_buf.size = VIDEO_BUFFER_SIZE;
             state = dirac_encoder_output ( encoder );
-            switch (state) {
+            switch (state)
+            {
             case ENC_STATE_AVAIL:
                 assert (encoder->enc_buf.size > 0);
 
                 outfile.write((char *)encoder->enc_buf.buffer,
                               encoder->enc_buf.size);
-                              pictures_written++;
                 break;
 
             case ENC_STATE_BUFFER:
                 break;
-
+            case ENC_STATE_EOS:
+                outfile.write((char *)encoder->enc_buf.buffer,
+                encoder->enc_buf.size);
+                go = false;
+                break;
             case ENC_STATE_INVALID:
                 std::cerr << "Invalid state. Unrecoverable Encoder Error. Quitting..."
                           << std::endl;
@@ -1149,30 +1235,21 @@ int main (int argc, char* argv[])
 
         } while (state == ENC_STATE_AVAIL);
 
-    } while (pictures_written/fields_factor <= (end_pos - start_pos) &&
-             end_of_file == false);
+    } while (go);
 
     stop_t = clock();
 
-    encoder->enc_buf.buffer = video_buf;
-    encoder->enc_buf.size = VIDEO_BUFFER_SIZE;
-    if (dirac_encoder_end_sequence( encoder ) > 0)
-    {
-        outfile.write((char *)encoder->enc_buf.buffer,
-                      encoder->enc_buf.size);
+    if ( verbose )
+        std::cout << "The resulting bit-rate at "
+                  << (double)encoder->enc_ctx.src_params.frame_rate.numerator/
+                     encoder->enc_ctx.src_params.frame_rate.denominator
+                  << "Hz is " << encoder->enc_seqstats.bit_rate
+                  << " bits/sec." << std::endl;
 
-        if ( verbose )
-            std::cout << "The resulting bit-rate at "
-                      << (double)encoder->enc_ctx.src_params.frame_rate.numerator/
-                          encoder->enc_ctx.src_params.frame_rate.denominator
-                      << "Hz is " << encoder->enc_seqstats.bit_rate
-                      << " bits/sec." << std::endl;
-
-        if ( verbose )
-            std::cout<<"Time per frame: "<<
-                    (double)(stop_t-start_t)/(double)(CLOCKS_PER_SEC*pictures_written/fields_factor);
-            std::cout<<std::endl<<std::endl;
-    }
+    if ( verbose )
+        std::cout<<"Time per frame: "<<
+           (double)(stop_t-start_t)/(double)(CLOCKS_PER_SEC*frames_loaded);
+        std::cout<<std::endl<<std::endl;
 
    /********************************************************************/
 
