@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: band_codec.cpp,v 1.40 2007/12/05 01:23:43 asuraparaju Exp $ $Name: Dirac_0_9_1 $
+* $Id: band_codec.cpp,v 1.42 2008/04/29 08:51:52 tjdwave Exp $ $Name: Dirac_0_10_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -60,7 +60,7 @@ BandCodec::BandCodec(SubbandByteIO* subband_byteio,
     m_is_intra(is_intra),
     m_bnum(band_num),
     m_node(band_list(band_num)),
-    m_last_qf_idx(m_node.QIndex())
+    m_last_qf_idx(m_node.QuantIndex())
 {
     if (m_node.Parent()!=0) 
         m_pnode=band_list(m_node.Parent());
@@ -111,11 +111,11 @@ void BandCodec::CodeCoeffBlock( const CodeBlock& code_block , CoeffArray& in_dat
     const int xend = code_block.Xend();
     const int yend = code_block.Yend();
  
-    const int qf_idx = code_block.QIndex();
+    const int qf_idx = code_block.QuantIndex();
 
     if ( m_node.UsingMultiQuants() )
     {
-          CodeQIndexOffset( qf_idx - m_last_qf_idx);
+          CodeQuantIndexOffset( qf_idx - m_last_qf_idx);
           m_last_qf_idx = qf_idx;
     }
 
@@ -211,7 +211,7 @@ inline void BandCodec::CodeVal( CoeffArray& in_data ,
     }
 }
 
-void BandCodec::CodeQIndexOffset( const int offset )
+void BandCodec::CodeQuantIndexOffset( const int offset )
 {
 
     const int abs_val = std::abs( offset );
@@ -282,23 +282,23 @@ void BandCodec::DecodeCoeffBlock( const CodeBlock& code_block , CoeffArray& out_
     const int xend = code_block.Xend();
     const int yend = code_block.Yend();
  
-    int qf_idx = m_node.QIndex();
+    int qf_idx = m_node.QuantIndex();
 
     if ( m_node.UsingMultiQuants() )
     {
-        qf_idx = m_last_qf_idx+DecodeQIndexOffset(); 
+        qf_idx = m_last_qf_idx+DecodeQuantIndexOffset(); 
         m_last_qf_idx = qf_idx;
     }
 
-    if (qf_idx > (int)dirac_quantiser_lists.MaxQIndex())
+    if (qf_idx > (int)dirac_quantiser_lists.MaxQuantIndex())
     {
         std::ostringstream errstr;
         errstr << "Quantiser index out of range [0.."  
-               << (int)dirac_quantiser_lists.MaxQIndex() << "]";
+               << (int)dirac_quantiser_lists.MaxQuantIndex() << "]";
         DIRAC_THROW_EXCEPTION(
             ERR_UNSUPPORTED_STREAM_DATA,
             errstr.str(),
-            SEVERITY_FRAME_ERROR);
+            SEVERITY_PICTURE_ERROR);
     }
 
     m_qf = dirac_quantiser_lists.QuantFactor4( qf_idx );
@@ -477,7 +477,7 @@ inline int BandCodec::ChooseSignContext( const CoeffArray& data , const int xpos
         return SIGN0_CTX;
 }
 
-int BandCodec::DecodeQIndexOffset()
+int BandCodec::DecodeQuantIndexOffset()
 {
     int offset = 1;
 
@@ -554,11 +554,11 @@ void LFBandCodec::CodeCoeffBlock( const CodeBlock& code_block , CoeffArray& in_d
 
     m_parent_notzero = false; //set parent to always be zero
 
-    const int qf_idx = code_block.QIndex();
+    const int qf_idx = code_block.QuantIndex();
 
     if ( m_node.UsingMultiQuants() )
     {
-        CodeQIndexOffset( qf_idx - m_last_qf_idx);
+        CodeQuantIndexOffset( qf_idx - m_last_qf_idx);
         m_last_qf_idx = qf_idx;
     }
 
@@ -622,23 +622,23 @@ void LFBandCodec::DecodeCoeffBlock( const CodeBlock& code_block , CoeffArray& ou
 
     m_parent_notzero = false;//set parent to always be zero    
 
-    int qf_idx = m_node.QIndex();
+    int qf_idx = m_node.QuantIndex();
 
     if ( m_node.UsingMultiQuants() )
     {
-        qf_idx += m_last_qf_idx+DecodeQIndexOffset(); 
+        qf_idx += m_last_qf_idx+DecodeQuantIndexOffset(); 
         m_last_qf_idx = qf_idx;
     }
 
-    if (qf_idx > (int)dirac_quantiser_lists.MaxQIndex())
+    if (qf_idx > (int)dirac_quantiser_lists.MaxQuantIndex())
     {
         std::ostringstream errstr;
         errstr << "Quantiser index out of range [0.."  
-               << (int)dirac_quantiser_lists.MaxQIndex() << "]";
+               << (int)dirac_quantiser_lists.MaxQuantIndex() << "]";
         DIRAC_THROW_EXCEPTION(
             ERR_UNSUPPORTED_STREAM_DATA,
             errstr.str(),
-            SEVERITY_FRAME_ERROR);
+            SEVERITY_PICTURE_ERROR);
     }
 
     m_qf = dirac_quantiser_lists.QuantFactor4( qf_idx );
@@ -707,11 +707,11 @@ void IntraDCBandCodec::CodeCoeffBlock( const CodeBlock& code_block , CoeffArray&
     
     CoeffType prediction;
 
-    const int qf_idx = code_block.QIndex();
+    const int qf_idx = code_block.QuantIndex();
 
     if ( m_node.UsingMultiQuants() )
     {
-          CodeQIndexOffset( qf_idx - m_last_qf_idx);
+          CodeQuantIndexOffset( qf_idx - m_last_qf_idx);
           m_last_qf_idx = qf_idx;
     }
 
@@ -770,11 +770,11 @@ void IntraDCBandCodec::DecodeCoeffBlock( const CodeBlock& code_block , CoeffArra
 
     m_parent_notzero = false; //set parent to always be zero
 
-    int qf_idx = m_node.QIndex();
+    int qf_idx = m_node.QuantIndex();
 
     if ( m_node.UsingMultiQuants() )
     {
-        qf_idx = DecodeQIndexOffset()+m_last_qf_idx;
+        qf_idx = DecodeQuantIndexOffset()+m_last_qf_idx;
         m_last_qf_idx = qf_idx;
     }
 
