@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: mot_comp.cpp,v 1.39 2008/01/24 10:10:02 tjdwave Exp $ $Name: Dirac_0_9_1 $
+* $Id: mot_comp.cpp,v 1.42 2008/04/29 08:51:52 tjdwave Exp $ $Name: Dirac_0_10_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -45,25 +45,25 @@
 #include <libdirac_common/mot_comp_mmx.h>
 #endif
 #include <libdirac_common/motion.h>
-#include <libdirac_common/frame_buffer.h>
+#include <libdirac_common/picture_buffer.h>
 using namespace dirac;
 
 using std::vector;
 
 
-#define NUM_USED_BLKS(w,sep,len) ((w+sep-(len-sep)/2-1)/sep)
+#define NUM_USED_BLKS(w,sep,len) ((w+sep+(len-sep)/2-1)/sep)
 
 //--public member functions--//
 ///////////////////////////////
 
-// Convenience function to perform motion compensation on a frame
-// Static function that motion compensates a frame. It uses the
+// Convenience function to perform motion compensation on a picture
+// Static function that motion compensates a picture. It uses the
 // MV precision value in the CodecParams to instantiate the
 // appropriate MotionCompensation sub-class.
-void MotionCompensator::CompensateFrame(const CodecParams &cp,
+void MotionCompensator::CompensatePicture(const CodecParams &cp,
                                         const AddOrSub direction ,
-                                        FrameBuffer& buffer ,
-                                        const int fnum,
+                                        PictureBuffer& buffer ,
+                                        const int pnum,
                                         const MvData& mv_data )
 {
     switch (cp.MVPrecision())
@@ -71,26 +71,26 @@ void MotionCompensator::CompensateFrame(const CodecParams &cp,
     case MV_PRECISION_EIGHTH_PIXEL:
     {
         MotionCompensator_EighthPixel my_comp(cp);
-        my_comp.CompensateFrame( direction , buffer , fnum , mv_data);
+        my_comp.CompensatePicture( direction , buffer , pnum , mv_data);
         break;
     }
     case MV_PRECISION_HALF_PIXEL:
     {
         MotionCompensator_HalfPixel my_comp(cp);
-        my_comp.CompensateFrame( direction , buffer , fnum , mv_data);
+        my_comp.CompensatePicture( direction , buffer , pnum , mv_data);
         break;
     }
     case MV_PRECISION_PIXEL:
     {
         MotionCompensator_Pixel my_comp(cp);
-        my_comp.CompensateFrame( direction , buffer , fnum , mv_data);
+        my_comp.CompensatePicture( direction , buffer , pnum , mv_data);
         break;
     }
     case MV_PRECISION_QUARTER_PIXEL:
     default:
     {
         MotionCompensator_QuarterPixel my_comp(cp);
-        my_comp.CompensateFrame( direction , buffer , fnum , mv_data);
+        my_comp.CompensatePicture( direction , buffer , pnum , mv_data);
         break;
     }
     }
@@ -127,24 +127,24 @@ MotionCompensator::~MotionCompensator()
     delete[] m_sub_block_weights;
 }
 
-//Called to perform motion compensated addition/subtraction on an entire frame.
-void MotionCompensator::CompensateFrame( const AddOrSub direction ,
-                                                    FrameBuffer& my_buffer ,
-                                                    int fnum ,
+//Called to perform motion compensated addition/subtraction on an entire picture.
+void MotionCompensator::CompensatePicture( const AddOrSub direction ,
+                                                    PictureBuffer& my_buffer ,
+                                                    int pnum ,
                                                     const MvData& mv_data)
 {
      m_add_or_sub = direction;
 
      int ref1_idx,ref2_idx;
-     Frame& my_frame=my_buffer.GetFrame(fnum);
-     const FrameSort& fsort=my_frame.GetFparams().FSort();
+     Picture& my_picture=my_buffer.GetPicture(pnum);
+     const PictureSort& fsort=my_picture.GetPparams().PicSort();
 
-     m_cformat = my_frame.GetFparams().CFormat();
+     m_cformat = my_picture.GetPparams().CFormat();
 
      if (fsort.IsInter())
      {//we can motion compensate
 
-         const std::vector<int>& refs=my_frame.GetFparams().Refs();
+         const std::vector<int>& refs=my_picture.GetPparams().Refs();
          if (refs.size()>0)
          {
              //extract the references
@@ -154,43 +154,43 @@ void MotionCompensator::CompensateFrame( const AddOrSub direction ,
              else
                  ref2_idx = refs[0];
 
-             const Frame& ref1frame = my_buffer.GetFrame(ref1_idx);
-             const Frame& ref2frame = refs.size() > 0 ? my_buffer.GetFrame(ref2_idx) : ref1frame;
+             const Picture& ref1pic = my_buffer.GetPicture(ref1_idx);
+             const Picture& ref2pic = refs.size() > 0 ? my_buffer.GetPicture(ref2_idx) : ref1pic;
 
              // Now check that references are marked correctly
-             if ( !ref1frame.GetFparams().FSort().IsRef() )
+             if ( !ref1pic.GetPparams().PicSort().IsRef() )
              {
-                 std::cout<<std::endl<<"WARNING! Reference frame (number "<<ref1_idx;
+                 std::cout<<std::endl<<"WARNING! Reference picture (number "<<ref1_idx;
                  std::cout<<") being used is not marked as a reference. Incorrect output is likely.";
              }
-             if ( ref1frame.GetFparams().FrameNum() != ref1_idx)
+             if ( ref1pic.GetPparams().PictureNum() != ref1_idx)
              {
-                 std::cout<<std::endl<<"WARNING! Reference frame (number "<<ref1_idx;
+                 std::cout<<std::endl<<"WARNING! Reference picture (number "<<ref1_idx;
                  std::cout<<") not available in buffer. Incorrect output is likely.";
              }
 
 
              if ( refs.size()>1 )
              {
-                 if ( !ref2frame.GetFparams().FSort().IsRef() )
+                 if ( !ref2pic.GetPparams().PicSort().IsRef() )
                  {
-                     std::cout<<std::endl<<"WARNING! Reference frame (number ";
+                     std::cout<<std::endl<<"WARNING! Reference picture (number ";
                      std::cout<<ref2_idx<<") being used is not marked as a reference. Incorrect output is likely.";
                  }
-                 if ( ref2frame.GetFparams().FrameNum() != ref2_idx)
+                 if ( ref2pic.GetPparams().PictureNum() != ref2_idx)
                  {
-                     std::cout<<std::endl<<"WARNING! Reference frame (number "<<ref2_idx;
+                     std::cout<<std::endl<<"WARNING! Reference picture (number "<<ref2_idx;
                      std::cout<<") not available in buffer. Incorrect output is likely.";
                  }
              }
 
              luma_or_chroma = true;
              //now do all the components
-             CompensateComponent( my_frame , ref1frame , ref2frame , mv_data , Y_COMP);
+             CompensateComponent( my_picture , ref1pic , ref2pic , mv_data , Y_COMP);
 
              luma_or_chroma = false;
-             CompensateComponent( my_frame , ref1frame , ref2frame , mv_data , U_COMP);
-             CompensateComponent( my_frame , ref1frame , ref2frame , mv_data , V_COMP);
+             CompensateComponent( my_picture , ref1pic , ref2pic , mv_data , U_COMP);
+             CompensateComponent( my_picture , ref1pic , ref2pic , mv_data , V_COMP);
          }
      }
 }
@@ -210,10 +210,10 @@ void MotionCompensator::ReConfig()
         m_bparams = m_cparams.ChromaBParams(2);
 
     // Calculate the shift required in horizontal and vertical direction for
-    // OBMC and the weighting bits for each reference frame.
+    // OBMC and the weighting bits for each reference picture.
 
-    // Total shift = shift assuming equal frame weights +
-    //               frame weights precision
+    // Total shift = shift assuming equal picture weights +
+    //               picture weights precision
     int blocks_per_mb_row = m_cparams.XNumBlocks()/m_cparams.XNumMB();
     int blocks_per_sb_row = blocks_per_mb_row>>1;
     int mb_xlen = m_bparams.Xblen()*blocks_per_mb_row - (m_bparams.Xblen()-m_bparams.Xbsep())*(blocks_per_mb_row-1);
@@ -233,7 +233,7 @@ void MotionCompensator::ReConfig()
     }
 
     // Firstly calculate the non-weighted Weighting blocks. i,e, assuming that
-    // the frame_weight for each reference frame is 1.
+    // the picture_weight for each reference picture is 1.
 
     // Calculate non-weighted Block Weights
     CalculateWeights( m_bparams.Xbsep(), m_bparams.Ybsep(), m_block_weights );
@@ -245,19 +245,19 @@ void MotionCompensator::ReConfig()
     CalculateWeights( sb_xsep, sb_ysep , m_sub_block_weights );
 }
 
-void MotionCompensator::CompensateComponent( Frame& picframe ,
-                                                        const Frame &ref1frame ,
-                                                        const Frame& ref2frame ,
+void MotionCompensator::CompensateComponent( Picture& pic ,
+                                                        const Picture &ref1pic ,
+                                                        const Picture& ref2pic ,
                                                         const MvData& mv_data ,
                                                         const CompSort cs)
 {
     // Set up references to pictures and references
-    PicArray& pic_data_out = picframe.Data( cs );
+    PicArray& pic_data_out = pic.Data( cs );
 
-    // Size of frame component being motion compensated
+    // Size of picture component being motion compensated
 
-    const PicArray& ref1up = ref1frame.UpData( cs );
-    const PicArray& ref2up = ref2frame.UpData( cs );
+    const PicArray& ref1up = ref1pic.UpData( cs );
+    const PicArray& ref2up = ref2pic.UpData( cs );
 
     // Set up a row of blocks which will contain the MC data, which
     // we'll add or subtract to pic_data_out
@@ -280,11 +280,11 @@ void MotionCompensator::CompensateComponent( Frame& picframe ,
         }
     }
 
-    ImageCoords orig_pic_size(picframe.GetFparams().OrigXl(), picframe.GetFparams().OrigYl());
+    ImageCoords pic_size(pic.GetPparams().Xl(), pic.GetPparams().Yl());
     if ( cs != Y_COMP )
     {
-        orig_pic_size.x = picframe.GetFparams().OrigChromaXl();
-        orig_pic_size.y = picframe.GetFparams().OrigChromaYl();
+        pic_size.x = pic.GetPparams().ChromaXl();
+        pic_size.y = pic.GetPparams().ChromaYl();
     }
 
 
@@ -292,7 +292,7 @@ void MotionCompensator::CompensateComponent( Frame& picframe ,
     const TwoDArray<ValueType>& dcarray = mv_data.DC( cs );
 
     // Set up references to the vectors
-    const int num_refs = picframe.GetFparams().Refs().size();
+    const int num_refs = pic.GetPparams().Refs().size();
     const MvArray* mv_array1;
     const MvArray* mv_array2;
     mv_array1 = &mv_data.Vectors(1);
@@ -318,17 +318,19 @@ void MotionCompensator::CompensateComponent( Frame& picframe ,
     int save_from_row = m_bparams.Ybsep()-m_bparams.Yoffset();
 
     // unpadded picture dimensions
-    const int x_end_data = pic_data_out.FirstX() + std::min(pic_data_out.LengthX(), orig_pic_size.x );
-    const int y_end_data = pic_data_out.FirstY() + std::min(pic_data_out.LengthY(), orig_pic_size.y );
+    const int x_end_data = pic_data_out.FirstX() + std::min(pic_data_out.LengthX(), pic_size.x );
+    const int y_end_data = pic_data_out.FirstY() + std::min(pic_data_out.LengthY(), pic_size.y );
 
     const int blocks_per_mb_row = m_cparams.XNumBlocks()/m_cparams.XNumMB();
     const int blocks_per_sb_row = blocks_per_mb_row>>1;
 
     // The picture does not contain integral number of blocks. So not all
     // blocks need to be processed. Compute the relevant blocks to be
-    // processed using the original picturesize and not the padded pic size
-    int y_num_blocks = NUM_USED_BLKS(orig_pic_size.y,m_bparams.Ybsep(),m_bparams.Yblen());
-    int x_num_blocks = NUM_USED_BLKS(orig_pic_size.x,m_bparams.Xbsep(),m_bparams.Xblen());
+    // processed 
+    int y_num_blocks = std::min((NUM_USED_BLKS(pic_size.y,m_bparams.Ybsep(),m_bparams.Yblen())), 
+                       m_cparams.YNumBlocks());
+    int x_num_blocks = std::min((NUM_USED_BLKS(pic_size.x,m_bparams.Xbsep(),m_bparams.Xblen())),  
+                       m_cparams.XNumBlocks());
 
     //Loop over all the block rows
     pos.y = -m_bparams.Yoffset();
@@ -341,29 +343,29 @@ void MotionCompensator::CompensateComponent( Frame& picframe ,
         {
             int split_mode =  mv_data.MBSplit()[yblock/blocks_per_mb_row][xblock/blocks_per_mb_row];
 
-            int blk_len_x, blk_len_y = m_bparams.Yblen();
+            int blk_x, blk_y = 1;
 
             switch (split_mode)
             {
             case 0: // processing superblock
-                blk_len_x = blocks_per_mb_row * m_bparams.Xblen();
+                blk_x = blocks_per_mb_row;
                 break;
             case 1: // processing sub-superblock
-                blk_len_x = blocks_per_sb_row * m_bparams.Xblen();
+                blk_x = blocks_per_sb_row;
                 break;
             case 2: // processing block
             default:
-                blk_len_x = m_bparams.Xblen();
+                blk_x = 1;
                 break;
             }
 
             //Decide which weights to use.
-            if (pos.x >=0 && (pos.x+blk_len_x) < orig_pic_size.x)
+            if (pos.x >=0 && (xblock+blk_x) < x_num_blocks)
             {
                 // block is entirely within picture in x direction
                 if (pos.y < 0)
                     wgt_idx = 1;
-                else if ((pos.y+blk_len_y) < orig_pic_size.y)
+                else if ((yblock+blk_y) < y_num_blocks)
                     wgt_idx = 4;
                 else
                     wgt_idx = 7;
@@ -373,7 +375,7 @@ void MotionCompensator::CompensateComponent( Frame& picframe ,
                 // left edge of block is outside picture in x direction
                 if (pos.y < 0)
                     wgt_idx = 0;
-                else if ((pos.y+blk_len_y) < orig_pic_size.y)
+                else if ((yblock+blk_y) < y_num_blocks)
                     wgt_idx = 3;
                 else
                     wgt_idx = 6;
@@ -383,7 +385,7 @@ void MotionCompensator::CompensateComponent( Frame& picframe ,
                 // right edge of block is outside picture in x direction
                 if (pos.y < 0)
                     wgt_idx = 2;
-                else if ((pos.y+blk_len_y) < orig_pic_size.y)
+                else if ((yblock+blk_y) < y_num_blocks)
                     wgt_idx = 5;
                 else
                     wgt_idx = 8;
@@ -419,7 +421,7 @@ void MotionCompensator::CompensateComponent( Frame& picframe ,
             mv2.x >>= xscale_shift;
             mv2.y >>= yscale_shift;
 
-            CompensateBlock(pic_data, pos, orig_pic_size, block_mode, dcarray[yblock][xblock], ref1up, mv1, ref2up, mv2, *wt);
+            CompensateBlock(pic_data, pos, pic_size, block_mode, dcarray[yblock][xblock], ref1up, mv1, ref2up, mv2, *wt);
 
             //Increment the block horizontal position
             pos.x += xincr;
@@ -458,7 +460,7 @@ void MotionCompensator::CompensateComponent( Frame& picframe ,
                 // for all the picture lines in the block row. Need only do this when we're
                 // subtracting.
 
-                for (int j=orig_pic_size.x; j<pic_data_out.LengthX() ; ++j )
+                for (int j=pic_size.x; j<pic_data_out.LengthX() ; ++j )
                 {
                     out_row[pic_data_out.FirstX()+j] = 0;
                 }
@@ -471,11 +473,11 @@ void MotionCompensator::CompensateComponent( Frame& picframe ,
             if (yblock == (y_num_blocks - 1))
             {
                 end_y += (m_bparams.Yblen()-m_bparams.Ybsep());
-                if (end_y > orig_pic_size.y)
-                    end_y = orig_pic_size.y;
+                if (end_y > pic_size.y)
+                    end_y = pic_size.y;
             }
 #if defined (HAVE_MMX)
-            CompensateComponentAddAndShift_mmx (start_y, end_y, 6, orig_pic_size,
+            CompensateComponentAddAndShift_mmx (start_y, end_y, 6, pic_size,
                                                  pic_data, pic_data_out);
 #else
             for ( int i = start_y, pic_y = 0; i < end_y; i++, pic_y++)
@@ -483,14 +485,14 @@ void MotionCompensator::CompensateComponent( Frame& picframe ,
                 ValueType *pic_row = pic_data[pic_y];
                 ValueType *out_row = pic_data_out[i];
 
-                for ( int j =0; j < orig_pic_size.x; j++)
+                for ( int j =0; j < pic_size.x; j++)
                 {
                     out_row[j] += static_cast<ValueType>( (pic_row[j] + 32) >> 6 );
                 }
                 // Pad the remaining pixels of the row with last truepic pixel val
-                for ( int j = orig_pic_size.x; j < pic_data.LengthX(); j++)
+                for ( int j = pic_size.x; j < pic_data.LengthX(); j++)
                 {
-                    out_row[j] = out_row[orig_pic_size.x-1];
+                    out_row[j] = out_row[pic_size.x-1];
                 }
             }
 #endif
@@ -510,7 +512,7 @@ void MotionCompensator::CompensateComponent( Frame& picframe ,
     {
         // Finally, now we've done all the blocks, we must set all padded lines 
         // below the last row equal to 0, if we're subtracting
-        for ( int y=orig_pic_size.y ; y<pic_data_out.LengthY() ; ++y )
+        for ( int y=pic_size.y ; y<pic_data_out.LengthY() ; ++y )
         {
             ValueType *out_row = pic_data_out[y];
             for ( int x=0 ; x<pic_data_out.LengthX() ; ++x )
@@ -525,8 +527,8 @@ void MotionCompensator::CompensateComponent( Frame& picframe ,
         // Edge extension
         // Finally, now we've done all the blocks, we must set all padded lines 
         // below the last row equal to same as last row, if we're adding
-        ValueType *last_row = &pic_data_out[orig_pic_size.y-1][0];
-        for ( int y=orig_pic_size.y ; y<pic_data_out.LengthY() ; ++y )
+        ValueType *last_row = &pic_data_out[pic_size.y-1][0];
+        for ( int y=pic_size.y ; y<pic_data_out.LengthY() ; ++y )
         {
             ValueType *out_row = pic_data_out[y];
             for ( int x=0 ; x<pic_data_out.LengthX() ; ++x )
@@ -541,7 +543,7 @@ void MotionCompensator::CompensateComponent( Frame& picframe ,
 void MotionCompensator::CompensateBlock(
                                     TwoDArray<ValueType> &pic_data ,
                                     const ImageCoords& pos ,
-                                    const ImageCoords& orig_pic_size ,
+                                    const ImageCoords& pic_size ,
                                     PredMode block_mode,
                                     ValueType dc,
                                     const PicArray &ref1up_data ,
@@ -552,8 +554,8 @@ void MotionCompensator::CompensateBlock(
 {
     //Coordinates in the image being written to.
     const ImageCoords start_pos( std::max(pos.x,0) , std::max(pos.y,0) );
-    const ImageCoords end_pos( std::min( pos.x + wt_array.LengthX() , orig_pic_size.x ) ,
-                               std::min( pos.y + wt_array.LengthY() , orig_pic_size.y ) );
+    const ImageCoords end_pos( std::min( pos.x + wt_array.LengthX() , pic_size.x ) ,
+                               std::min( pos.y + wt_array.LengthY() , pic_size.y ) );
 
     // Check if we are within original picture bounds
     if (start_pos.x >= end_pos.x || start_pos.y >= end_pos.y)
@@ -564,16 +566,16 @@ void MotionCompensator::CompensateBlock(
 
     if(block_mode == REF1_ONLY)
     {
-        BlockPixelPred(val1, pos, orig_pic_size, ref1up_data, mv1);
+        BlockPixelPred(val1, pos, pic_size, ref1up_data, mv1);
     }
     else if (block_mode == REF2_ONLY)
     {
-        BlockPixelPred(val1, pos, orig_pic_size, ref2up_data, mv2);
+        BlockPixelPred(val1, pos, pic_size, ref2up_data, mv2);
     }
     else if(block_mode == REF1AND2)
     {
-        BlockPixelPred(val1, pos, orig_pic_size, ref1up_data, mv1);
-        BlockPixelPred(val2, pos, orig_pic_size, ref2up_data, mv2);
+        BlockPixelPred(val1, pos, pic_size, ref1up_data, mv1);
+        BlockPixelPred(val2, pos, pic_size, ref2up_data, mv2);
     }
     else
     {//we have a DC block.
@@ -629,7 +631,7 @@ void MotionCompensator::AdjustBlockByRefWeights (
     if (m_cparams.CustomRefWeights())
     {
         int ref_wt_prec_bias = 1;
-        for (int i = m_cparams.FrameWeightsBits()-1; i > 0; --i)
+        for (int i = m_cparams.PictureWeightsBits()-1; i > 0; --i)
         {
             ref_wt_prec_bias <<= 1;
         }
@@ -660,7 +662,7 @@ void MotionCompensator::AdjustBlockByRefWeights (
         {
             for (int x = 0; x < val1_block.LengthX(); ++x)
             {
-                val1_block[y][x] = (val1_block[y][x] + ref_wt_prec_bias) >> m_cparams.FrameWeightsBits();
+                val1_block[y][x] = (val1_block[y][x] + ref_wt_prec_bias) >> m_cparams.PictureWeightsBits();
             }
         }
     }
@@ -704,7 +706,7 @@ void MotionCompensator::CalculateWeights( int xbsep, int ybsep,
                                           TwoDArray<ValueType>* wts_array)
 {
     // Firstly calculate the non-weighted Weighting blocks. i,e, assuming that
-    // the frame_weight for each reference frame is 1.
+    // the picture_weight for each reference picture is 1.
     // We can create all nine weighting blocks by calculating values
     // for four blocks and mirroring them to generate the others.
     CreateBlock( xbsep, ybsep, false , false , wts_array[0] );
@@ -846,7 +848,7 @@ MotionCompensator_Pixel::MotionCompensator_Pixel( const CodecParams &cp ) :
 void MotionCompensator_Pixel::BlockPixelPred(
                                     TwoDArray<ValueType> &block_data ,
                                     const ImageCoords& pos,
-                                    const ImageCoords& orig_pic_size ,
+                                    const ImageCoords& pic_size ,
                                     const PicArray &refup_data ,
                                     const MVector &mv)
 {
@@ -860,8 +862,8 @@ void MotionCompensator_Pixel::BlockPixelPred(
     //the reference image.
     const int refXlen = refup_data.LengthX();
     //const int refYlen = refup_data.LengthY();
-    const int trueRefXlen = (orig_pic_size.x << 1) - 1;
-    const int trueRefYlen = (orig_pic_size.y << 1) - 1;
+    const int trueRefXlen = (pic_size.x << 1) - 1;
+    const int trueRefYlen = (pic_size.y << 1) - 1;
     bool do_bounds_checking = false;
 
     //Check if there are going to be any problems copying the block from
@@ -915,7 +917,7 @@ MotionCompensator_HalfPixel::MotionCompensator_HalfPixel( const CodecParams &cp
 void MotionCompensator_HalfPixel::BlockPixelPred( 
                                   TwoDArray<ValueType> &block_data ,
                                   const ImageCoords& pos ,
-                                  const ImageCoords& orig_pic_size ,
+                                  const ImageCoords& pic_size ,
                                   const PicArray &refup_data ,
                                   const MVector &mv)
 {
@@ -927,8 +929,8 @@ void MotionCompensator_HalfPixel::BlockPixelPred(
     //outsidethe reference image.
     const int refXlen = refup_data.LengthX();
     //const int refYlen = refup_data.LengthY();
-    const int trueRefXlen = (orig_pic_size.x << 1) - 1;
-    const int trueRefYlen = (orig_pic_size.y << 1) - 1;
+    const int trueRefXlen = (pic_size.x << 1) - 1;
+    const int trueRefYlen = (pic_size.y << 1) - 1;
 
     bool do_bounds_checking = false;
 
@@ -985,7 +987,7 @@ MotionCompensator_QuarterPixel::MotionCompensator_QuarterPixel( const CodecParam
 void MotionCompensator_QuarterPixel::BlockPixelPred(
                                      TwoDArray<ValueType> &block_data ,
                                      const ImageCoords& pos ,
-                                     const ImageCoords& orig_pic_size ,
+                                     const ImageCoords& pic_size ,
                                      const PicArray &refup_data ,
                                      const MVector &mv)
 {
@@ -1004,8 +1006,8 @@ void MotionCompensator_QuarterPixel::BlockPixelPred(
     //the reference image.
     const int refXlen = refup_data.LengthX();
     //const int refYlen = refup_data.LengthY();
-    const int trueRefXlen = (orig_pic_size.x<<1) - 1;
-    const int trueRefYlen = (orig_pic_size.y<<1) - 1;
+    const int trueRefXlen = (pic_size.x<<1) - 1;
+    const int trueRefYlen = (pic_size.y<<1) - 1;
 
     ValueType *block_curr = &block_data[0][0];
 
@@ -1108,7 +1110,7 @@ MotionCompensator_EighthPixel::MotionCompensator_EighthPixel( const CodecParams
 void MotionCompensator_EighthPixel::BlockPixelPred(
                                     TwoDArray<ValueType> &block_data ,
                                     const ImageCoords& pos ,
-                                    const ImageCoords& orig_pic_size ,
+                                    const ImageCoords& pic_size ,
                                     const PicArray &refup_data ,
                                     const MVector &mv)
 {
@@ -1134,8 +1136,8 @@ void MotionCompensator_EighthPixel::BlockPixelPred(
     //the reference image.
     const int refXlen = refup_data.LengthX();
     //const int refYlen = refup_data.LengthY();
-    const int trueRefXlen = (orig_pic_size.x << 1) - 1;
-    const int trueRefYlen = (orig_pic_size.y << 1) - 1;
+    const int trueRefXlen = (pic_size.x << 1) - 1;
+    const int trueRefYlen = (pic_size.y << 1) - 1;
     bool do_bounds_checking = false;
 
     //Check if there are going to be any problems copying the block from
