@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: motion.h,v 1.21 2007/04/11 08:08:49 tjdwave Exp $ $Name: Dirac_0_9_1 $
+* $Id: motion.h,v 1.23 2008/03/14 08:17:36 asuraparaju Exp $ $Name: Dirac_0_10_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -226,7 +226,7 @@ namespace dirac
             \param  ynumMB  the number of MBs vertically
             \param  xnumblocks  the number of blocks horizontally
             \param  ynumblocks  the number of blocks vertically
-            \param  num_refs  the number of references being used for the frame
+            \param  num_refs  the number of references being used for the picture
         */
         MvData( const int xnumMB, const int ynumMB , 
                 const int xnumblocks, const int ynumblocks ,  const int num_refs);
@@ -236,7 +236,7 @@ namespace dirac
             Constructor. Numbers of blocks derived from the number of MBs
             \param  xnumMB  the number of MBs horizontally
             \param  ynumMB  the number of MBs vertically
-            \param  num_refs  the number of references being used for the frame
+            \param  num_refs  the number of references being used for the picture
         */
         MvData( const int xnumMB, const int ynumMB ,  const int num_refs);
 
@@ -283,7 +283,7 @@ namespace dirac
         const OneDArray<float>& GlobalMotionParameters(const int ref_id) const { return *( m_gm_params[ref_id] ); }
 
         //! Return the number of reference frames
-        const unsigned int NumRefs()const {return m_num_refs;}
+        unsigned int NumRefs()const {return m_num_refs;}
 
     private:
         // Initialises the arrays of data
@@ -328,7 +328,7 @@ namespace dirac
             \param  ynumMB  the number of MBs vertically
             \param  xnumblocks  the number of blocks horizontally
             \param  ynumblocks  the number of blocks vertically
-            \param  num_refs  the number of references being used for the frame
+            \param  num_refs  the number of references being used for the picture
         */
         MEData( const int xnumMB, const int ynumMB , 
                 const int xnumblocks, const int ynumblocks , const int num_refs = 2);
@@ -338,7 +338,7 @@ namespace dirac
             Constructor. Numbers of blocks derived from the number of MBs
             \param  xnumMB  the number of MBs horizontally
             \param  ynumMB  the number of MBs vertically
-            \param  num_refs  the number of references being used for the frame
+            \param  num_refs  the number of references being used for the picture
         */
         MEData( const int xnumMB, const int ynumMB , const int num_refs = 2);
 
