@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: mv_codec.cpp,v 1.32 2007/12/12 11:10:54 tjdwave Exp $ $Name: Dirac_0_9_1 $
+* $Id: mv_codec.cpp,v 1.33 2008/02/01 19:52:30 tjdwave Exp $ $Name: Dirac_0_10_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -588,7 +588,7 @@ void DCCodec::ResetAll()
 ValueType DCCodec::Prediction(const TwoDArray < ValueType > & dcdata,
                                     const TwoDArray < PredMode > & preddata) const
 {
-    std::vector < unsigned int >  nbrs; 
+    std::vector < int >  nbrs; 
     PredMode pmode;
     ValueType result = 0; 
     
@@ -596,18 +596,18 @@ ValueType DCCodec::Prediction(const TwoDArray < ValueType > & dcdata,
     {
         pmode = preddata[m_b_yp-1][m_b_xp]; 
         if (pmode == INTRA) 
-            nbrs.push_back( (unsigned int) dcdata[m_b_yp-1][m_b_xp] ); 
+            nbrs.push_back( (int) dcdata[m_b_yp-1][m_b_xp] ); 
         
         pmode = preddata[m_b_yp-1][m_b_xp-1]; 
         if (pmode == INTRA)
-            nbrs.push_back((unsigned int)dcdata[m_b_yp-1][m_b_xp-1] ); 
+            nbrs.push_back((int)dcdata[m_b_yp-1][m_b_xp-1] ); 
         
         pmode = preddata[m_b_yp][m_b_xp-1]; 
         if (pmode == INTRA)        
-            nbrs.push_back( (unsigned int) dcdata[m_b_yp][m_b_xp-1] ); 
+            nbrs.push_back( (int) dcdata[m_b_yp][m_b_xp-1] ); 
         
         if (nbrs.size() > 0)
-            result = ValueType(GetUMean(nbrs));     
+            result = ValueType(GetSMean(nbrs));     
     }
     else if (m_b_xp > 0 && m_b_yp == 0)
     {
@@ -621,7 +621,6 @@ ValueType DCCodec::Prediction(const TwoDArray < ValueType > & dcdata,
         if (pmode == INTRA)
             result = dcdata[m_b_yp-1][0]; 
     }
-
     return result;
 }
 
