@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: me_mode_decn.h,v 1.12 2007/03/19 16:19:00 asuraparaju Exp $ $Name: Dirac_0_9_1 $
+* $Id: me_mode_decn.h,v 1.13 2008/01/31 11:25:19 tjdwave Exp $ $Name: Dirac_0_10_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -43,7 +43,7 @@
 
 namespace dirac
 {
-    class FrameBuffer;
+    class PictureBuffer;
 
     //! Decides between macroblock and block prediction modes.
     /*!
@@ -88,10 +88,10 @@ namespace dirac
         /*!
             Does the mode decision
             \param    my_buffer    the buffer of all the relevant frames
-            \param    frame_num    the frame number for which motion estimation is being done
+            \param    frame_num    the picture number for which motion estimation is being done
             \param    me_data    the motion vector data into which decisions will be written
          */
-        void DoModeDecn( const FrameBuffer& my_buffer , int frame_num , MEData& me_data);
+        void DoModeDecn( const PictureBuffer& my_buffer , int frame_num , MEData& me_data);
 
     private:
         ModeDecider( const ModeDecider& cpy );//private, body-less copy constructor: this class should not be copied
@@ -120,7 +120,7 @@ namespace dirac
         float GetDCVar( const ValueType dc_val , const ValueType dc_pred);
 
          // Member data
-        FrameSort fsort;
+        PictureSort fsort;
 
         //! A local reference to the encoder params
         const EncoderParams& m_encparams;
