@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: draw_overlay.h,v 1.4 2004/11/22 13:42:33 asuraparaju Exp $ $Name: Dirac_0_9_1 $
+* $Id: draw_overlay.h,v 1.6 2008/03/14 08:17:37 asuraparaju Exp $ $Name: Dirac_0_10_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -40,8 +40,8 @@
 
 
 #include <libdirac_common/motion.h>
-#include <libdirac_common/frame.h>
-using dirac::Frame;
+#include <libdirac_common/picture.h>
+using dirac::Picture;
 using dirac::PicArray;
 using dirac::MvArray;
 
@@ -51,40 +51,40 @@ namespace dirac_instr
 {
 #define NO_REF -1
 
-    //! Class encapsulating parameters for drawing the frame
-    class DrawFrameMotionParams
+    //! Class encapsulating parameters for drawing the picture
+    class DrawPictureMotionParams
     {
     public :
 
         //! Default constuctor, does nothing
-        DrawFrameMotionParams() {}
+        DrawPictureMotionParams() {}
 
         //! Default destructor, does nothing
-        ~DrawFrameMotionParams() {}
+        ~DrawPictureMotionParams() {}
         //! Gets...
         //! Returns luma motion vector block height
-        const int MvYBlockY() const {return m_mv_Y_block_y;}
+        int MvYBlockY() const {return m_mv_Y_block_y;}
         
         //! Returns luma motion vector block width
-        const int MvYBlockX() const {return m_mv_Y_block_x;}
+        int MvYBlockX() const {return m_mv_Y_block_x;}
 
         //! Returns chroma motion vector height
-        const int MvUVBlockY() const {return m_mv_UV_block_y;}
+        int MvUVBlockY() const {return m_mv_UV_block_y;}
 
         //! Returns chroma motion vector width
-        const int MvUVBlockX() const {return m_mv_UV_block_x;}
+        int MvUVBlockX() const {return m_mv_UV_block_x;}
 
         //! Returns chroma - luma vertical smaple ratio
-        const int ChromaFactorY() const {return m_chroma_factor_y;}
+        int ChromaFactorY() const {return m_chroma_factor_y;}
         
         //! Returns chroma - luma horizontal sample ratio
-        const int ChromaFactorX() const {return m_chroma_factor_x;}
+        int ChromaFactorX() const {return m_chroma_factor_x;}
 
         //! Returns original picture height
-        const int PicY() const {return m_pic_y;}
+        int PicY() const {return m_pic_y;}
 
         //! Returns original picture width
-        const int PicX() const {return m_pic_x;}
+        int PicX() const {return m_pic_x;}
 
         //! Sets...
         //! Set luma motion vector block height    
@@ -135,7 +135,7 @@ namespace dirac_instr
     {
     public :
         //! Constructor
-        DrawOverlay(Frame &, DrawFrameMotionParams &);
+        DrawOverlay(Picture &, DrawPictureMotionParams &);
         
         //! Destructor
         virtual ~DrawOverlay();
@@ -152,14 +152,14 @@ namespace dirac_instr
         //                                                        //
         ////////////////////////////////////////////////////////////
 
-        //! Draws frame numbers for both references
+        //! Draws picture numbers for both references
         void DrawReferenceNumbers(int, int);
         
-        //! Draws frame number for chosen reference
+        //! Draws picture number for chosen reference
         void DrawReferenceNumber(int, int);
         
-        //! Draws current frame number
-        void DrawFrameNumber(int);
+        //! Draws current picture number
+        void DrawPictureNumber(int);
         
         //! Draws a character / number / symbol
         void DrawCharacter(const PicArray &, int, int);
@@ -185,11 +185,11 @@ namespace dirac_instr
         //! Colours an 8x8 block referenced by TL chroma pixel
         void DrawBlockUV(int, int, int, int);
         
-        //! Frame data
-        Frame & m_frame;
+        //! Picture data
+        Picture & m_picture;
         
         //! Block parameters and chroma scaling
-        DrawFrameMotionParams & m_draw_params;
+        DrawPictureMotionParams & m_draw_params;
         
         //! Symbols
         OverlaySymbols m_symbols;
