@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: motion_colour_arrows.h,v 1.2 2004/11/22 13:42:33 asuraparaju Exp $ $Name: Dirac_0_9_1 $
+* $Id: motion_colour_arrows.h,v 1.3 2008/01/31 11:25:20 tjdwave Exp $ $Name: Dirac_0_10_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -55,7 +55,7 @@ namespace dirac_instr
         /*
             Calls DrawMotionArrows constructor
         */
-        DrawMotionColourArrows(Frame &, DrawFrameMotionParams &, const MvArray &, int, int);
+        DrawMotionColourArrows(Picture &, DrawPictureMotionParams &, const MvArray &, int, int);
         
         //! Destructor
         ~DrawMotionColourArrows();
