@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: overlay.cpp,v 1.9 2007/08/31 13:10:47 asuraparaju Exp $ $Name: Dirac_0_9_1 $
+* $Id: overlay.cpp,v 1.10 2008/01/31 11:25:20 tjdwave Exp $ $Name: Dirac_0_10_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -41,83 +41,83 @@ using namespace dirac_instr;
 // using namespace dirac;
 
 // constructor
-Overlay::Overlay (const OverlayParams & overlayparams, Frame & frame)
+Overlay::Overlay (const OverlayParams & overlayparams, Picture & picture)
 :
     m_oparams(overlayparams),
-    m_frame(frame)
+    m_picture(picture)
 {
-    CalculateFactors(frame.GetFparams().CFormat());
+    CalculateFactors(picture.GetPparams().CFormat());
 }
 
 // destructor - doesn't do anything!
 Overlay::~Overlay ()
 {}
 
-// process intra frame
-void Overlay::ProcessFrame()
+// process intra picture
+void Overlay::ProcessPicture()
 {
     // if a mid-grey background is selected instead of the original luma, do that
     if (m_oparams.Background()==0)
     {
-        for (int j=0; j<=m_frame.Ydata().LastY(); ++j)
+        for (int j=0; j<=m_picture.Ydata().LastY(); ++j)
         {
-            for (int i=0; i<=m_frame.Ydata().LastX(); ++i)
-                m_frame.Ydata()[j][i]=0;
+            for (int i=0; i<=m_picture.Ydata().LastX(); ++i)
+                m_picture.Ydata()[j][i]=0;
         }
     }
 
     // set chroma arrays to zero
-    for (int j=0; j<m_frame.Udata().LengthY(); ++j)
+    for (int j=0; j<m_picture.Udata().LengthY(); ++j)
     {
-        for (int i=0; i<m_frame.Udata().LengthX(); ++i)
+        for (int i=0; i<m_picture.Udata().LengthX(); ++i)
         {
-            m_frame.Udata()[j][i]=0;
-            m_frame.Vdata()[j][i]=0;
+            m_picture.Udata()[j][i]=0;
+            m_picture.Vdata()[j][i]=0;
         }
     }
 
-    // in order to draw frame number and 'I' label, create a dummy DrawPredMode object
+    // in order to draw picture number and 'I' label, create a dummy DrawPredMode object
     // and call appropriate functions. Not the most elegant!
     MEData me_data(1,1,1,1);
-    DrawPredMode dummy(m_frame, m_draw_params, me_data.Mode());
-    dummy.DrawFrameNumber(m_frame.GetFparams().FrameNum());
+    DrawPredMode dummy(m_picture, m_draw_params, me_data.Mode());
+    dummy.DrawPictureNumber(m_picture.GetPparams().PictureNum());
     dummy.DrawCharacter(dummy.Symbols().LetterI(), 16, 0);
 }
 
-// process motion-compensated frame
-void Overlay::ProcessFrame(const MEData & me_data, const OLBParams & block_params)
+// process motion-compensated picture
+void Overlay::ProcessPicture(const MEData & me_data, const OLBParams & block_params)
 {
     m_draw_params.SetMvYBlockY(block_params.Ybsep());
     m_draw_params.SetMvYBlockX(block_params.Xbsep());
     m_draw_params.SetMvUVBlockY(block_params.Ybsep()/m_draw_params.ChromaFactorY());
     m_draw_params.SetMvUVBlockX(block_params.Xbsep()/m_draw_params.ChromaFactorX());
-    m_draw_params.SetPicY(m_frame.Ydata().LengthY());
-    m_draw_params.SetPicX(m_frame.Ydata().LengthX());
+    m_draw_params.SetPicY(m_picture.Ydata().LengthY());
+    m_draw_params.SetPicX(m_picture.Ydata().LengthX());
 
     //std::cerr<<std::endl<<"Pic: "<<m_draw_params.PicY()<<" "<<m_draw_params.PicX();
 
-    PadFrame(me_data);
+    PadPicture(me_data);
 
     // if a mid-grey background is selected instead of the original luma, do that
     if (m_oparams.Background()==0)
     {
-        for (int j=0; j<=m_frame.Ydata().LastY(); ++j)
+        for (int j=0; j<=m_picture.Ydata().LastY(); ++j)
         {
-            for (int i=0; i<=m_frame.Ydata().LastX(); ++i)
-                m_frame.Ydata()[j][i]=0;
+            for (int i=0; i<=m_picture.Ydata().LastX(); ++i)
+                m_picture.Ydata()[j][i]=0;
         }
     }
 
     // set up references
-    if (m_oparams.Reference() == 2 && (m_frame.GetFparams().Refs().size() < 2 || m_frame.GetFparams().Refs()[0] == m_frame.GetFparams().Refs()[1]))
+    if (m_oparams.Reference() == 2 && (m_picture.GetPparams().Refs().size() < 2 || m_picture.GetPparams().Refs()[0] == m_picture.GetPparams().Refs()[1]))
     {
         m_ref = NO_REF;
         m_mv_scale = 1;
     }
     else
     {
-        m_ref = m_frame.GetFparams().Refs()[m_oparams.Reference()-1];
-        m_mv_scale = std::abs(m_frame.GetFparams().FrameNum()-m_frame.GetFparams().Refs()[m_oparams.Reference()-1]); // scale motion vectors for temporal difference
+        m_ref = m_picture.GetPparams().Refs()[m_oparams.Reference()-1];
+        m_mv_scale = std::abs(m_picture.GetPparams().PictureNum()-m_picture.GetPparams().Refs()[m_oparams.Reference()-1]); // scale motion vectors for temporal difference
     }
 
     // now do the overlaying!
@@ -158,44 +158,44 @@ void Overlay::DoOverlay(const MEData & me_data)
     switch (m_oparams.Option())
     {
         case motion_arrows :
-            draw_overlay_ptr = new DrawMotionArrows(m_frame, m_draw_params,
+            draw_overlay_ptr = new DrawMotionArrows(m_picture, m_draw_params,
                                                     me_data.Vectors(m_oparams.Reference()), m_mv_scale);
             break;
 
         case motion_colour_arrows :
-            draw_overlay_ptr = new DrawMotionColourArrows(m_frame, m_draw_params,
+            draw_overlay_ptr = new DrawMotionColourArrows(m_picture, m_draw_params,
                                                           me_data.Vectors(m_oparams.Reference()), m_mv_scale,
                                                           m_oparams.MvClip());
             break;
 
         case motion_colour :
-            draw_overlay_ptr = new DrawMotionColour(m_frame, m_draw_params,
+            draw_overlay_ptr = new DrawMotionColour(m_picture, m_draw_params,
                                                     me_data.Vectors(m_oparams.Reference()),
                                                     m_mv_scale, m_oparams.MvClip());
             break;
 
         case SAD :
-            draw_overlay_ptr = new DrawSad(m_frame, m_draw_params, me_data.PredCosts(m_oparams.Reference()),
+            draw_overlay_ptr = new DrawSad(m_picture, m_draw_params, me_data.PredCosts(m_oparams.Reference()),
                                            me_data.Mode(), m_oparams.SADClip());
             break;
 
         case split_mode :
-            draw_overlay_ptr = new DrawSplitMode(m_frame, m_draw_params, me_data.MBSplit());
+            draw_overlay_ptr = new DrawSplitMode(m_picture, m_draw_params, me_data.MBSplit());
             break;
 
         case pred_mode :
-            draw_overlay_ptr = new DrawPredMode(m_frame, m_draw_params, me_data.Mode());
+            draw_overlay_ptr = new DrawPredMode(m_picture, m_draw_params, me_data.Mode());
             break;
 
         case gm_arrows :
-            draw_overlay_ptr = new DrawMotionArrows(m_frame,
+            draw_overlay_ptr = new DrawMotionArrows(m_picture,
                                                     m_draw_params,
                                                     me_data.GlobalMotionVectors(m_oparams.Reference()),
                                                     m_mv_scale);
             break;
 
         case gm_colour_arrows :
-            draw_overlay_ptr = new DrawMotionColourArrows(m_frame,
+            draw_overlay_ptr = new DrawMotionColourArrows(m_picture,
                                                           m_draw_params,
                                                           me_data.GlobalMotionVectors(m_oparams.Reference()),
                                                           m_mv_scale,
@@ -203,7 +203,7 @@ void Overlay::DoOverlay(const MEData & me_data)
             break;
 
         case gm_colour :
-            draw_overlay_ptr = new DrawMotionColour(m_frame,
+            draw_overlay_ptr = new DrawMotionColour(m_picture,
                                                     m_draw_params,
                                                     me_data.GlobalMotionVectors(m_oparams.Reference()),
                                                     m_mv_scale,
@@ -215,7 +215,7 @@ void Overlay::DoOverlay(const MEData & me_data)
             
             GlobalMotionDifference( me_data, mv_diff );
             
-            draw_overlay_ptr = new DrawMotionArrows(m_frame,
+            draw_overlay_ptr = new DrawMotionArrows(m_picture,
                                                     m_draw_params,
                                                     mv_diff,
                                                     m_mv_scale);
@@ -225,7 +225,7 @@ void Overlay::DoOverlay(const MEData & me_data)
 
             GlobalMotionDifference( me_data, mv_diff );
             
-            draw_overlay_ptr = new DrawMotionColourArrows(m_frame,
+            draw_overlay_ptr = new DrawMotionColourArrows(m_picture,
                                                           m_draw_params,
                                                           mv_diff,
                                                           m_mv_scale,
@@ -236,7 +236,7 @@ void Overlay::DoOverlay(const MEData & me_data)
 
             GlobalMotionDifference( me_data, mv_diff );
             
-            draw_overlay_ptr = new DrawMotionColour(m_frame,
+            draw_overlay_ptr = new DrawMotionColour(m_picture,
                                                     m_draw_params,
                                                     mv_diff,
                                                     m_mv_scale,
@@ -245,28 +245,28 @@ void Overlay::DoOverlay(const MEData & me_data)
             break;
 
         case gm_inliers :
-            draw_overlay_ptr = new DrawGMInliers(m_frame, m_draw_params, me_data.GlobalMotionInliers(m_oparams.Reference()));
+            draw_overlay_ptr = new DrawGMInliers(m_picture, m_draw_params, me_data.GlobalMotionInliers(m_oparams.Reference()));
             
             break;
     }
     
-    // if we are trying to overlay information which does not exist because frame only
-    // has a single reference, remove chroma and display frame number and legend
+    // if we are trying to overlay information which does not exist because picture only
+    // has a single reference, remove chroma and display picture number and legend
     if (m_ref==-1 && m_oparams.Option() != pred_mode && m_oparams.Option() != split_mode)
     {
-        for (int y=0; y<m_frame.Udata().LengthY(); ++y)
+        for (int y=0; y<m_picture.Udata().LengthY(); ++y)
         {
-            for (int x=0; x<m_frame.Udata().LengthX(); ++x)
+            for (int x=0; x<m_picture.Udata().LengthX(); ++x)
             {
-                m_frame.Udata()[y][x] = 0;
-                m_frame.Vdata()[y][x] = 0;
+                m_picture.Udata()[y][x] = 0;
+                m_picture.Vdata()[y][x] = 0;
             }
         }
         
         if (m_oparams.Legend())
             draw_overlay_ptr->DrawLegend();
             
-        draw_overlay_ptr->DrawFrameNumber(m_frame.GetFparams().FrameNum());        
+        draw_overlay_ptr->DrawPictureNumber(m_picture.GetPparams().PictureNum());        
         draw_overlay_ptr->DrawReferenceNumber(m_oparams.Reference(), m_ref);
     }
     // otherwise, loop over motion vector blocks and draw as appropriate to overlay
@@ -285,10 +285,10 @@ void Overlay::DoOverlay(const MEData & me_data)
         if (m_oparams.Legend())
             draw_overlay_ptr->DrawLegend();
             
-        draw_overlay_ptr->DrawFrameNumber(m_frame.GetFparams().FrameNum());
+        draw_overlay_ptr->DrawPictureNumber(m_picture.GetPparams().PictureNum());
 
         if (m_oparams.Option() == pred_mode || m_oparams.Option() == split_mode)
-            draw_overlay_ptr->DrawReferenceNumbers(m_frame.GetFparams().Refs()[0], m_frame.GetFparams().Refs()[1]);
+            draw_overlay_ptr->DrawReferenceNumbers(m_picture.GetPparams().Refs()[0], m_picture.GetPparams().Refs()[1]);
         else
             draw_overlay_ptr->DrawReferenceNumber(m_oparams.Reference(), m_ref);
     }
@@ -321,61 +321,61 @@ void Overlay::CalculateFactors(const ChromaFormat & cformat)
     }
 }
 
-// calculate if frame requires padding due to requirement of integer number of macroblocks
-void Overlay::PadFrame(const MEData & me_data)
+// calculate if picture requires padding due to requirement of integer number of macroblocks
+void Overlay::PadPicture(const MEData & me_data)
 {
-    int frame_x = m_frame.Ydata().LengthX();
-    int frame_y = m_frame.Ydata().LengthY();
+    int picture_x = m_picture.Ydata().LengthX();
+    int picture_y = m_picture.Ydata().LengthY();
 
-    // copy frame components
-    PicArray Ydata(m_frame.Ydata());
-    PicArray Udata(m_frame.Udata());
-    PicArray Vdata(m_frame.Vdata());
+    // copy picture components
+    PicArray Ydata(m_picture.Ydata());
+    PicArray Udata(m_picture.Udata());
+    PicArray Vdata(m_picture.Vdata());
 
     // if there is not an integer number of macroblocks horizontally, pad until there is
-    if (m_frame.Ydata().LengthX() % me_data.MBSplit().LengthX() != 0)
+    if (m_picture.Ydata().LengthX() % me_data.MBSplit().LengthX() != 0)
     {
         do
         {
-            ++frame_x;
+            ++picture_x;
         }
-        while (frame_x % me_data.MBSplit().LengthX() != 0);       
+        while (picture_x % me_data.MBSplit().LengthX() != 0);       
     }
 
     // if there is not an integer number of macroblocks vertically, pad until there is
-    if (m_frame.Ydata().LengthX() % me_data.MBSplit().LengthY() != 0)
+    if (m_picture.Ydata().LengthX() % me_data.MBSplit().LengthY() != 0)
     {
         do
         {
-            ++frame_y;
+            ++picture_y;
         }
-        while (frame_y % me_data.MBSplit().LengthY() != 0);
+        while (picture_y % me_data.MBSplit().LengthY() != 0);
     }
 
-    // if padding was required in either horizontal or vertical, adjust frame size and reload component data
-    if (m_frame.Ydata().LengthX() % me_data.MBSplit().LengthX() != 0 || m_frame.Ydata().LengthY() % me_data.MBSplit().LengthY() != 0)
+    // if padding was required in either horizontal or vertical, adjust picture size and reload component data
+    if (m_picture.Ydata().LengthX() % me_data.MBSplit().LengthX() != 0 || m_picture.Ydata().LengthY() % me_data.MBSplit().LengthY() != 0)
     {
-        m_frame.Ydata().Resize(frame_y, frame_x);
-        m_frame.Udata().Resize(frame_y / m_draw_params.ChromaFactorY(), frame_x / m_draw_params.ChromaFactorX());
-        m_frame.Vdata().Resize(frame_y / m_draw_params.ChromaFactorY(), frame_x / m_draw_params.ChromaFactorX());
+        m_picture.Ydata().Resize(picture_y, picture_x);
+        m_picture.Udata().Resize(picture_y / m_draw_params.ChromaFactorY(), picture_x / m_draw_params.ChromaFactorX());
+        m_picture.Vdata().Resize(picture_y / m_draw_params.ChromaFactorY(), picture_x / m_draw_params.ChromaFactorX());
        
         for (int j=0; j<Ydata.LengthY(); ++j)
         {
             for (int i=0; i<Ydata.LengthX(); ++i)
             {
-                m_frame.Ydata()[j][i]=Ydata[j][i];
+                m_picture.Ydata()[j][i]=Ydata[j][i];
             }
             // pad the columns on the rhs using the edge value
-            for (int i=Ydata.LengthX(); i <  m_frame.Ydata().LengthX(); ++i)
-                m_frame.Ydata()[j][i] = m_frame.Ydata()[j][Ydata.LengthX()-1];
+            for (int i=Ydata.LengthX(); i <  m_picture.Ydata().LengthX(); ++i)
+                m_picture.Ydata()[j][i] = m_picture.Ydata()[j][Ydata.LengthX()-1];
         }
         // do the padded lines using the last true line
-        for (int j=Ydata.LengthY(); j<m_frame.Ydata().LengthY(); ++j)
+        for (int j=Ydata.LengthY(); j<m_picture.Ydata().LengthY(); ++j)
         {
             //std::cerr << "Processing row " << j  << std::endl;
-            for (int i=0; i <  m_frame.Ydata().LengthX(); ++i)
+            for (int i=0; i <  m_picture.Ydata().LengthX(); ++i)
             {
-                m_frame.Ydata()[j][i] = m_frame.Ydata()[Ydata.LengthY()-1][i];
+                m_picture.Ydata()[j][i] = m_picture.Ydata()[Ydata.LengthY()-1][i];
             }
         }
         
@@ -383,24 +383,24 @@ void Overlay::PadFrame(const MEData & me_data)
         {
             for (int i=0; i<Udata.LengthX(); ++i)
             {
-                m_frame.Udata()[j][i]=Udata[j][i];
-                m_frame.Vdata()[j][i]=Vdata[j][i];
+                m_picture.Udata()[j][i]=Udata[j][i];
+                m_picture.Vdata()[j][i]=Vdata[j][i];
             }
             // pad the columns on the rhs using the edge value
-            for (int i=Udata.LengthX(); i <  m_frame.Udata().LengthX(); ++i)
+            for (int i=Udata.LengthX(); i <  m_picture.Udata().LengthX(); ++i)
             {
-                m_frame.Udata()[j][i] = m_frame.Udata()[j][Udata.LengthX()-1];
-                m_frame.Vdata()[j][i] = m_frame.Vdata()[j][Udata.LengthX()-1];
+                m_picture.Udata()[j][i] = m_picture.Udata()[j][Udata.LengthX()-1];
+                m_picture.Vdata()[j][i] = m_picture.Vdata()[j][Udata.LengthX()-1];
             }
         }
         // do the padded lines using the last true line
-        for (int j=Udata.LengthY(); j<m_frame.Udata().LengthY(); ++j)
+        for (int j=Udata.LengthY(); j<m_picture.Udata().LengthY(); ++j)
         {
             //std::cerr << "Processing row " << j  << std::endl;
-            for (int i=0; i <  m_frame.Udata().LengthX(); ++i)
+            for (int i=0; i <  m_picture.Udata().LengthX(); ++i)
             {
-                m_frame.Udata()[j][i] = m_frame.Udata()[Udata.LengthY()-1][i];
-                m_frame.Vdata()[j][i] = m_frame.Vdata()[Udata.LengthY()-1][i];
+                m_picture.Udata()[j][i] = m_picture.Udata()[Udata.LengthY()-1][i];
+                m_picture.Vdata()[j][i] = m_picture.Vdata()[Udata.LengthY()-1][i];
             }
         }
 
