@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: pred_mode.h,v 1.2 2004/11/22 13:42:33 asuraparaju Exp $ $Name: Dirac_0_9_1 $
+* $Id: pred_mode.h,v 1.3 2008/01/31 11:25:20 tjdwave Exp $ $Name: Dirac_0_10_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -47,7 +47,7 @@ namespace dirac_instr
     //! Class to carry out overlay of prediction mode
     /*
         Sub-clas of DrawOverlay.
-        Displays which reference frame is used as prediction for block
+        Displays which reference picture is used as prediction for block
     */
     class DrawPredMode : public DrawOverlay
     {
@@ -57,7 +57,7 @@ namespace dirac_instr
         /*
             Calls DrawOverlay constructor
         */
-        DrawPredMode(Frame &, DrawFrameMotionParams &, 
+        DrawPredMode(Picture &, DrawPictureMotionParams &, 
                     const TwoDArray<PredMode> &);
 
         //! Destructor
