@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: sad.h,v 1.2 2004/11/22 13:42:33 asuraparaju Exp $ $Name: Dirac_0_9_1 $
+* $Id: sad.h,v 1.3 2008/01/31 11:25:20 tjdwave Exp $ $Name: Dirac_0_10_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -56,7 +56,7 @@ namespace dirac_instr
         /*
             Calls DrawOverlay constructor
         */
-        DrawSad(Frame &, DrawFrameMotionParams &, const TwoDArray<MvCostData> &, const TwoDArray<PredMode>&, int);
+        DrawSad(Picture &, DrawPictureMotionParams &, const TwoDArray<MvCostData> &, const TwoDArray<PredMode>&, int);
         //! Destructor
         ~DrawSad();
 
