@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: split_mode.h,v 1.2 2004/11/22 13:42:33 asuraparaju Exp $ $Name: Dirac_0_9_1 $
+* $Id: split_mode.h,v 1.3 2008/01/31 11:25:20 tjdwave Exp $ $Name: Dirac_0_10_0 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -40,7 +40,7 @@
 
 #include <util/instrumentation/libdirac_instrument/draw_overlay.h>
 using dirac::TwoDArray;
-using dirac::Frame;
+using dirac::Picture;
 
 namespace dirac_instr
 {
@@ -55,7 +55,7 @@ namespace dirac_instr
         /*
             Calls DrawOverlay constructor
         */
-        DrawSplitMode(Frame &, DrawFrameMotionParams &, const TwoDArray<int> &);
+        DrawSplitMode(Picture &, DrawPictureMotionParams &, const TwoDArray<int> &);
         
         //! Destructor
         ~DrawSplitMode();
